@@ -116,7 +116,7 @@ class Dataset():
             self.dataset_dir = os.path.join(zipfile_or_directory, 'data')
         elif os.path.isfile(zipfile_or_directory):
             try:
-                self.dataset_zip = zipfile.ZipFile(zipfile_or_directory)
+                self.dataset_zip = zipfile.ZipFile(zipfile_or_directory)    # pylint:disable=consider-using-with
                 self.dataset_dir = 'ncbi_dataset/data'
             except zipfile.BadZipFile as e:
                 logger.error('Bad zipfile: %s', e)
